==> mmpose-0.12.0.tar.gz: mmpose-0.12.0/mmpose/datasets/datasets/__init__.py <==
from ...deprecated import (TopDownFreiHandDataset, TopDownOneHand10KDataset,
                           TopDownPanopticDataset)
from .bottom_up import (BottomUpAicDataset, BottomUpCocoDataset,
                        BottomUpCrowdPoseDataset, BottomUpMhpDataset)
from .face import (Face300WDataset, FaceAFLWDataset, FaceCOFWDataset,
                   FaceWFLWDataset)
from .fashion import DeepFashionDataset
from .hand import (FreiHandDataset, InterHand2DDataset, InterHand3DDataset,
                   OneHand10KDataset, PanopticDataset)
from .mesh import (MeshAdversarialDataset, MeshH36MDataset, MeshMixDataset,
                   MoshDataset)
from .top_down import (TopDownAicDataset, TopDownCocoDataset,
                       TopDownCocoWholeBodyDataset, TopDownCrowdPoseDataset,
                       TopDownJhmdbDataset, TopDownMhpDataset,
                       TopDownMpiiDataset, TopDownMpiiTrbDataset,
                       TopDownOCHumanDataset, TopDownPoseTrack18Dataset)

__all__ = [
    'TopDownCocoDataset', 'BottomUpCocoDataset', 'BottomUpMhpDataset',
    'BottomUpAicDataset', 'TopDownMpiiDataset', 'TopDownMpiiTrbDataset',
    'OneHand10KDataset', 'PanopticDataset', 'FreiHandDataset',
    'InterHand2DDataset', 'InterHand3DDataset', 'TopDownOCHumanDataset',
    'TopDownAicDataset', 'TopDownCocoWholeBodyDataset', 'MeshH36MDataset',
    'MeshMixDataset', 'MoshDataset', 'MeshAdversarialDataset',
    'TopDownCrowdPoseDataset', 'BottomUpCrowdPoseDataset',
    'TopDownFreiHandDataset', 'TopDownOneHand10KDataset',
    'TopDownPanopticDataset', 'TopDownPoseTrack18Dataset',
    'TopDownJhmdbDataset', 'TopDownMhpDataset', 'DeepFashionDataset',
    'Face300WDataset', 'FaceAFLWDataset', 'FaceWFLWDataset', 'FaceCOFWDataset'
]

==> mmpose-0.13.0.tar.gz: mmpose-0.13.0/mmpose/datasets/datasets/__init__.py <==
from ...deprecated import (TopDownFreiHandDataset, TopDownOneHand10KDataset,
                           TopDownPanopticDataset)
from .body3d import Body3DH36MDataset
from .bottom_up import (BottomUpAicDataset, BottomUpCocoDataset,
                        BottomUpCrowdPoseDataset, BottomUpMhpDataset)
from .face import (Face300WDataset, FaceAFLWDataset, FaceCOFWDataset,
                   FaceWFLWDataset)
from .fashion import DeepFashionDataset
from .hand import (FreiHandDataset, InterHand2DDataset, InterHand3DDataset,
                   OneHand10KDataset, PanopticDataset)
from .mesh import (MeshAdversarialDataset, MeshH36MDataset, MeshMixDataset,
                   MoshDataset)
from .top_down import (TopDownAicDataset, TopDownCocoDataset,
                       TopDownCocoWholeBodyDataset, TopDownCrowdPoseDataset,
                       TopDownJhmdbDataset, TopDownMhpDataset,
                       TopDownMpiiDataset, TopDownMpiiTrbDataset,
                       TopDownOCHumanDataset, TopDownPoseTrack18Dataset)

__all__ = [
    'TopDownCocoDataset', 'BottomUpCocoDataset', 'BottomUpMhpDataset',
    'BottomUpAicDataset', 'TopDownMpiiDataset', 'TopDownMpiiTrbDataset',
    'OneHand10KDataset', 'PanopticDataset', 'FreiHandDataset',
    'InterHand2DDataset', 'InterHand3DDataset', 'TopDownOCHumanDataset',
    'TopDownAicDataset', 'TopDownCocoWholeBodyDataset', 'MeshH36MDataset',
    'MeshMixDataset', 'MoshDataset', 'MeshAdversarialDataset',
    'TopDownCrowdPoseDataset', 'BottomUpCrowdPoseDataset',
    'TopDownFreiHandDataset', 'TopDownOneHand10KDataset',
    'TopDownPanopticDataset', 'TopDownPoseTrack18Dataset',
    'TopDownJhmdbDataset', 'TopDownMhpDataset', 'DeepFashionDataset',
    'Face300WDataset', 'FaceAFLWDataset', 'FaceWFLWDataset', 'FaceCOFWDataset',
    'Body3DH36MDataset'
]
